@@ -16,13 +16,17 @@
 pub mod error;
 pub mod util;
 
-pub mod message;
+pub mod endpoint;
 pub mod proto;
 
-mod conn;
+mod client;
+mod server;
 
 pub mod netapp;
 pub mod peering;
 
-pub use netapp::*;
-pub use util::NodeID;
+pub use crate::netapp::*;
+pub use util::{NetworkKey, NodeID, NodeKey};
+
+#[cfg(test)]
+mod test;
